@@ -26,6 +26,6 @@ class NewJobForm(Form):
     max_sites = IntegerField(u'Maximum number of sites:<br>(use 0 for default settings)', [validators.NumberRange(max=20000)], default=0)
     min_w = IntegerField(u'Minimum motif width:', default=6)
     max_w = IntegerField(u'Maximum motif width:', default=14)
-    max_start_finding_time = IntegerField(u'Maximum start finding time:<br>(seconds; 0 for unlimited; should be used on large data sets)', default=0)
+    max_start_finding_time = IntegerField(u'Maximum start finding time:<br>(seconds; 0 for unlimited; should be changed for large data sets)', default=0)
     
 
